#!/usr/bin/php
<?php
// Copyright (C) 2008 - 2012 vortexbox.org
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// Changelog:
//
// Fri Mar 02 2012 <admin@vortexbox.org>
// * Fixed the Blu-Ray code to accept titles with commas in them. 
//		Many thanks to forum user waltonb for this fix!
//
// Sat Feb 25 2012 Ron Olsen <ronolsen@comcast.net>
// * Move putenv calls to start of script so makemkv-con is always invoked as user root.
// * Call getdate() to compute start_time.
//
// Wed Jun 01 2011 Ron Olsen <ronolsen@comcast.net>
// * Call get-cddevice to get the device name instead of hard-coding /dev/sr0.
//
error_reporting(E_ERROR);

// Change user and home to root so makemkv-con can get the Blu-ray track info.

putenv("USER=root");
putenv("HOME=/root");

// cleanup
exec("mkdir -p /storage/tmp/ripper.tmp/");
exec("rm -rf /storage/tmp/ripper.tmp/*");

// Get device name

$cddevice=exec("/opt/vortexbox/get-cddevice");
echo "Using device $cddevice\n";

echo "Reading Blu-ray track info. This may take a while...\n";
// extract title and chapter info from the blu-ray.
exec("/usr/bin/makemkvcon info dev:".$cddevice." -r > /tmp/docd_helper.tmp");
$track_info = file("/tmp/docd_helper.tmp");

// defaults in case we can't parse info data
$movie_title = "Unknown_Title";
$long_track = 0;
$length = 0;

for ($i = 0; $i < count($track_info); ++$i) {
  // find title
  $parts = preg_match("/^CINFO:30,0,\"(.*)\"/", $track_info[$i], $t);
  if ($parts != 0) {
    echo "Got Title: $t[1]\n";
    $movie_title = $t[1];
    continue;
  }
  // find longest track
  $parts = preg_match("/^TINFO:(\d+),30,0,\".*\s,\s(.*)\s(\S+)\"/", $track_info[$i], $t);
  if ($parts != 0) {
    if ($t[3] == "MB") {
      // only consider tracks >1GB
      echo "Track $t[1] has $t[2] units of $t[3]... skipping.\n";
    } else {
      echo "Track $t[1] has $t[2] units of $t[3]\n";
      if ($t[2] > $length) {
	$length = $t[2];
	$long_track = $t[1];
      }
    }
  }
}

// Rip the Blu-ray!

echo "\nRipping ".$movie_title." (track ".$long_track.")\n\n";
exec("/usr/bin/makemkvcon mkv --decrypt --progress=-stdout --minlength=120 dev:$cddevice ".($long_track)." /storage/tmp/ripper.tmp >> /var/log/cdrip.log");
$movie_title_path = "/storage/movies/".$movie_title.".mkv";
	
// If movie name already exists create a new directory title
if (file_exists($movie_title_path)) {
	$movie_title_path = "/storage/movies/".$movie_title."-".$start_time[0].".mkv";
	echo "Movie already exists, renaming movie to: $movie_title_path\n";
} 

exec('mv /storage/tmp/ripper.tmp/*.mkv "'.$movie_title_path.'"');

$end_time = getdate();
$difference = $end_time[0] - $start_time[0];
echo "\nRipping took ". intval($difference/60) ." minutes and ". ($difference - (intval($difference/60)*60))." seconds.\n";

if ($fp = fopen("/tmp/docd_helper_dvdname.tmp", 'w')) {
	fwrite($fp, $movie_title);
	fclose($fp); 
} else {
	echo 'Config file unwritable... '; 
}

if (file_exists("/etc/vortexbox/riptomp4")) {
	exec ('mkdir -p "/storage/movies/mp4/'.$directory_name.'"');
	echo "Converting .mkv tracks to .mp4, this can take a while...\n";

	if ($multirip == 1) {	
	  $path = "/storage/movies/".$directory_name;
	  $dh = opendir($path);
	  $i=1;
	  while (($file = readdir($dh)) !== false) {
	   if($file != "." && $file != "..") {
	      echo "Encoding /storage/movies/mp4/".$directory_name."/".substr($file,0,-4).".mp4\n";
		  exec('/usr/bin/ffmpeg -y -i "/storage/movies/'.$movie_title.'/'.$file.'" -loglevel 1 -vcodec mpeg2video -b 5500k -acodec copy -f vob -copyts "/storage/movies/mp4/'.$directory_name.'/'.substr($file,0,-4).'.mp4"');
		  $i++;
	   }
	  }
	  closedir($dh);
	} else {
	 	echo "Encoding /storage/movies/mp4/".$directory_name."/".$movie_title.".mp4\n";
		exec('/usr/bin/ffmpeg -y -i "/storage/movies/'.$movie_title.'.mkv" -loglevel 1 -vcodec mpeg2video -b 5500k -acodec copy -f vob -copyts "/storage/movies/mp4/'.$directory_name.'/'.$movie_title.'.mp4"');
	}
	
	// Create xml for Windows Media Center
	$myFile = "/storage/movies/mp4/".$directory_name."/".$movie_title.".dvdid.xml";
	$fh = fopen($myFile, 'w') or die("can't open file");
	$stringData = '<?xml version="1.0" encoding="utf-8"?>'."\n";
	fwrite($fh, $stringData);
	$stringData = "<Disc>\n";
	fwrite($fh, $stringData);
	$stringData = "     <Name>".$movie_title."</Name>\n";
	fwrite($fh, $stringData);
	$stringData = "     <ID>".strtoupper($dvdid)."</ID>\n";
	fwrite($fh, $stringData);
	$stringData = "</Disc>\n";
	fwrite($fh, $stringData);
	fclose($fh);

	echo "Finished converting to mp4.\n";
}

if (file_exists("/etc/vortexbox/riptom2ts")) {
	exec ('mkdir -p "/storage/movies/m2ts/'.$directory_name.'"');
	echo "Converting .mkv tracks to .m2ts for PS3, this can take a while...\n";

  	if ($multirip == 1) {	
  	  $path = "/storage/movies/".$directory_name;
 	  $m2path = "/storage/movies/m2ts/".$directory_name;
  	  $dh = opendir($path);
  	  while (($file = readdir($dh)) !== false) {
 	   if(!is_dir($file)) {
 	      echo "Encoding: ".$m2path."/".substr($file,0,-4).".m2ts\n";
		  exec('/usr/bin/ffmpeg -y -i "'.$path.'/'.$file.'" -loglevel 1 -vcodec copy -acodec "'.$m2path.'/'.substr($file,0,-4).'.m2ts"');
  	   }
  	  }
	  closedir($dh);
	} else {
	 	echo "Encoding /storage/movies/m2ts/".$directory_name."/".$movie_title.".m2ts\n";
		exec('/usr/bin/ffmpeg -y -i "/storage/movies/'.$movie_title.'.mkv" -loglevel 1 -vcodec copy -acodec copy "/storage/movies/m2ts/'.$directory_name.'/'.$movie_title.'.m2ts"');
	}
	
	echo "Finished converting to m2ts.\n";
}
?>
