#!/bin/sh
# Copyright (C) 2008 - 2013 vortexbox.org
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#

function ipaddr {
 IPADDR=`/sbin/ifconfig eth0 2>/dev/null|gawk '/inet addr/{print $2}'|gawk -F: '{print $2}'`
 IPADDR2=`/sbin/ifconfig eth1 2>/dev/null|gawk '/inet addr/{print $2}'|gawk -F: '{print $2}'`
 IPADDR3=`/sbin/ifconfig br0 2>/dev/null|gawk '/inet addr/{print $2}'|gawk -F: '{print $2}'`

 if [ "$IPADDR" != "" ]; then
	echo "For web access to your VortexBox web GUI use http://$IPADDR";
 elif [ "$IPADDR2" != "" ]; then
	echo "For web access to your VortexBox web GUI use http://$IPADDR2";
 elif [ "$IPADDR3" != "" ]; then
	echo "For web access to your VortexBox web GUI use http://$IPADDR3";	
 else	
	echo "No IP address for eth0: (DHCP not working?)";
 fi
}

function startservices {
	chmod 755 /opt/vortexbox/motd.sh && /opt/vortexbox/motd.sh > /etc/issue

	# Start process that require a 30 second delay
	/opt/vortexbox/30sec_delay.sh & > /dev/null 2>&1

	# Make sure Samba is working
	/bin/systemctl restart smb.service > /dev/null 2>&1
	/bin/systemctl restart nmb.service > /dev/null 2>&1

	# Only start minidlna if the user wants it autostarted on reboot
	if /bin/systemctl is-enabled minidlna.service | grep enabled > /dev/null ; then
		/bin/systemctl restart minidlna.service > /dev/null 2>&1
	fi

	# Make sure sonosweb startes
	echo "Restart Sonos Web." >> /var/tmp/startup.log
	if /bin/systemctl is-enabled sonosweb.service | grep enabled > /dev/null ; then
		/bin/systemctl restart sonosweb.service > /dev/null 2>&1
	fi

	# Start Wi-Fi gateway	
	if [ -f /etc/vortexbox/gateway.mode ] ; then
		/sbin/service dnsmasq start > /dev/null 2>&1
		/opt/vortexbox/nat_router.sh
	fi

	# Start AP mode
	if [ -f /etc/vortexbox/ap.mode ] ; then
		/opt/vortexbox/ap_mode.sh
	fi

	# Start Auraliti Server mode
	if [ -f /etc/vortexbox/auraliti-server ] ; then
		if [ ! -d /export ] ; then
			mkdir /export
			ln -s /storage/music/flac /export/flac
		fi
		if ! grep export /etc/exports > /dev/null ; then
			/bin/systemctl stop nfs-server.service
			echo "/export *(ro)" >> /etc/exports
			/bin/systemctl start nfs-server.service
		fi
		/bin/systemctl stop avahi-daemon.service
		/bin/systemctl start avahi-daemon.service
		/usr/bin/avahi-set-host-name auraliti-server
	fi
	
	# Bluetooth
	if [ -f /usr/bin/hcitool ] ; then
	  if hcitool dev | grep hci0 >/dev/null 2>&1 ; then
		/usr/local/sbin/simple-agent &
	  fi
	fi
	
	/opt/vortexbox/myvb.php > /dev/null 2>&1

	# Start user defined process that require the network to be up
	if [ -f /usr/local/sbin/network_up.sh ] ; then
		/usr/local/sbin/network_up.sh &
	fi

}

#------------------
# Start of script
#------------------

echo `date` > /var/tmp/startup.log
echo "Startup started" >> /var/tmp/startup.log

# Start user defined custom network
if [ -f /usr/local/sbin/custom_network.sh ] ; then
 chmod +x /usr/local/sbin/custom_network.sh
 /usr/local/sbin/custom_network.sh &
fi	

# Check to see if network is up yet
if ! ping -c 1 -w 5 "google.com" &>/dev/null ; then
 for (( c=1; ; c++ ))
 do
   sleep 5
   IPBR0=`/sbin/ifconfig br0 2>/dev/null|gawk '/inet addr/{print $2}'|gawk -F: '{print $2}'`
   # Network is never comming up. Lets build our own netowrk.
   if [ c==5 ] && [ "$IPBR0"=="" ] && [ -f /etc/vortexbox/ap.mode ] ; then
     echo "Network timed out. Starting our own local network..."
	 /sbin/ifconfig br0 192.168.19.1 netmask 255.255.255.0
	 /usr/sbin/dnsmasq --dhcp-range=192.168.19.100,192.168.19.150,12h --dhcp-option=3,192.168.19.1 --no-hosts --no-resolv
	 startservices
     exit
   fi
   
   if ping -c 1 -w 5 "google.com" &>/dev/null ; then
    echo ""
	echo "Network is finally up."
	/opt/vortexbox/motd.sh > /etc/issue
	ipaddr
	echo ""
	
	echo "Adjusting time..."
	/sbin/service ntpd stop > /dev/null 2>&1
	/usr/sbin/ntpdate pool.ntp.org > /dev/null 2>&1
	/sbin/hwclock --systohc
	/sbin/service ntpd start > /dev/null 2>&1
	
	echo "Restarting some services that require the network..."
	startservices

    break
   fi
 done
else
 echo ""
 echo "Network is up."
 ipaddr
 echo ""
 echo "Adjusting time..."
 /sbin/service ntpd stop > /dev/null 2>&1
 /usr/sbin/ntpdate pool.ntp.org > /dev/null 2>&1
 /sbin/hwclock --systohc
 /sbin/service ntpd start > /dev/null 2>&1
 startservices
fi
